@@ -1,9 +1,9 @@
-import urllib
-import urllib2
+import json
 
+from django.utils.six.moves.urllib.parse import urlencode
+from django.utils.six.moves.urllib.request import urlopen
 from django.core.management.base import CommandError
-from django.utils import simplejson as json
-from django.conf import settings
+
 
 def call(method, data, post=False):
     """
@@ -14,12 +14,12 @@ def call(method, data, post=False):
     if post:
         # POST request
         url += "/"
-        data = urllib.urlencode(data)
+        data = urlencode(data)
     else:
         # GET request
-        url += "?%s" % urllib.urlencode(data)
+        url += "?%s" % urlencode(data)
         data = ''
-    res = json.load(urllib2.urlopen(url, data))
+    res = json.load(urlopen(url, data))
     if not res['succeeded']:
         raise CommandError("'%s' failed: %s\nData: %s" % (method, res['code'], data))
     return res['message']
